package com.eurekaclient.eurekaclientuserservice.controller;

import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Optional;

/*
<code>@RestController</code>: This annotation marks the class as a Spring MVC controller that handles incoming HTTP requests. It indicates that the class's methods will return data that should be directly serialized into the HTTP response body, making it suitable for building RESTful APIs.

<code>@RequestMapping("/user")</code>: This annotation at the class level specifies the base URL path ("/user") that this controller will handle. Any HTTP request starting with this path will be directed to methods within this controller.

<code>public class ApiController { ... }</code>: This defines a Java class named "ApiController" that serves as the REST controller for handling user-related requests.

<code>@GetMapping("/welcome")</code>: This annotation is applied to the "welcome" method, specifying that it will handle HTTP GET requests to the endpoint "/user/welcome." It maps this method to a specific URL route.

<code>public ResponseEntity&lt;String&gt; welcome() { ... }</code>: This is a Java method that handles the incoming HTTP GET request. It returns a `ResponseEntity` object containing a `String`. The `ResponseEntity` allows you to control the HTTP response, including the status code and headers.

<code>return ResponseEntity.of(Optional.of("Welcome to user service."))</code>: In this line, a `ResponseEntity` is created and initialized with the message "Welcome to user service." wrapped in an `Optional`. The response will contain this message, and the HTTP status will be set to 200 (OK) by default.

In summary, the "ApiController" class defines a RESTful controller in a Spring-based application. It handles GET requests to the "/user/welcome" endpoint, responding with a "Welcome to user service." message as an HTTP response. The `@RestController` and `@RequestMapping` annotations define its behavior, and the `@GetMapping` annotation specifies the route for the welcome method.
 */
@RestController
@RequestMapping("/user")
public class ApiController {

    // HTTP GET - http://localhost:9300/api/welcome
    @GetMapping("/welcome")
    public ResponseEntity<String> welcome() {
        return ResponseEntity.of(Optional.of("Welcome to user service."));
    }
}
