package com.eurekaserver.eurekaserver;

import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.cloud.netflix.eureka.server.EnableEurekaServer;

/*
<code>@SpringBootApplication</code>: This annotation is used to mark the class as a Spring Boot application. It combines three commonly used annotations: <code>@Configuration</code>, <code>@EnableAutoConfiguration</code>, and <code>@ComponentScan</code>. It tells Spring Boot to configure the application, enable auto-configuration based on the classpath, and scan for components (e.g., beans, controllers, etc.) in the package where the application class is located.

<code>@EnableEurekaServer</code>: This annotation is specific to Spring Cloud Netflix Eureka, a service discovery and registry server. When applied to a Spring Boot application, it configures the application to act as a Eureka Server, which allows it to maintain a registry of services (microservices) that are registered with it and provides service discovery capabilities to other microservices.

<code>public static void main(String[] args)</code>: This is the main method of the class. It serves as the entry point for the application. When you execute the <code>main</code> method, it starts the Spring Boot application.

<code>SpringApplication.run(EurekaserverApplication.class, args)</code>: This line of code starts the Spring Boot application. It takes two arguments: the main application class (<code>EurekaserverApplication.class</code>) and the command-line arguments (<code>args</code>). It initializes the Spring application context, loads the application's configuration, and starts the embedded web server (if needed).

In summary, this class sets up a Spring Boot application with the <code>@EnableEurekaServer</code> annotation, making it function as a Eureka Server, which can be used for service registration and discovery in a microservices architecture. When you run this application, it starts the Eureka Server and provides a web-based dashboard where you can monitor and manage registered services.
 */
@SpringBootApplication
@EnableEurekaServer
public class EurekaserverApplication {

    public static void main(String[] args) {
        SpringApplication.run(EurekaserverApplication.class, args);
    }
}
